==> apigateway-1.8.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/apigateway/CfnDomainNameV2Props.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * Properties for defining a `AWS::ApiGatewayV2::DomainName`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-domainname.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.16.0 (build 98909b5)", date = "2019-09-10T21:22:40.398Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnDomainNameV2Props extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::ApiGatewayV2::DomainName.DomainName`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-domainname.html#cfn-apigatewayv2-domainname-domainname
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getDomainName();

    /**
     * `AWS::ApiGatewayV2::DomainName.DomainNameConfigurations`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-domainname.html#cfn-apigatewayv2-domainname-domainnameconfigurations
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getDomainNameConfigurations();

    /**
     * `AWS::ApiGatewayV2::DomainName.Tags`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-domainname.html#cfn-apigatewayv2-domainname-tags
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getTags();

    /**
     * @return a {@link Builder} of {@link CfnDomainNameV2Props}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnDomainNameV2Props}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Builder {
        private java.lang.String domainName;
        private java.lang.Object domainNameConfigurations;
        private java.lang.Object tags;

        /**
         * Sets the value of DomainName
         * @param domainName `AWS::ApiGatewayV2::DomainName.DomainName`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder domainName(java.lang.String domainName) {
            this.domainName = domainName;
            return this;
        }

        /**
         * Sets the value of DomainNameConfigurations
         * @param domainNameConfigurations `AWS::ApiGatewayV2::DomainName.DomainNameConfigurations`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder domainNameConfigurations(software.amazon.awscdk.core.IResolvable domainNameConfigurations) {
            this.domainNameConfigurations = domainNameConfigurations;
            return this;
        }

        /**
         * Sets the value of DomainNameConfigurations
         * @param domainNameConfigurations `AWS::ApiGatewayV2::DomainName.DomainNameConfigurations`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder domainNameConfigurations(java.util.List<java.lang.Object> domainNameConfigurations) {
            this.domainNameConfigurations = domainNameConfigurations;
            return this;
        }

        /**
         * Sets the value of Tags
         * @param tags `AWS::ApiGatewayV2::DomainName.Tags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder tags(java.lang.Object tags) {
            this.tags = tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnDomainNameV2Props}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnDomainNameV2Props build() {
            return new Jsii$Proxy(domainName, domainNameConfigurations, tags);
        }

    }

    /**
     * An implementation for {@link CfnDomainNameV2Props}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnDomainNameV2Props {
        private final java.lang.String domainName;
        private final java.lang.Object domainNameConfigurations;
        private final java.lang.Object tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.domainName = this.jsiiGet("domainName", java.lang.String.class);
            this.domainNameConfigurations = this.jsiiGet("domainNameConfigurations", java.lang.Object.class);
            this.tags = this.jsiiGet("tags", java.lang.Object.class);
        }


        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.String domainName, java.lang.Object domainNameConfigurations, java.lang.Object tags) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.domainName = java.util.Objects.requireNonNull(domainName, "domainName is required");
            this.domainNameConfigurations = domainNameConfigurations;
            this.tags = tags;
        }

        @Override
        public java.lang.String getDomainName() {
            return this.domainName;
        }

        @Override
        public java.lang.Object getDomainNameConfigurations() {
            return this.domainNameConfigurations;
        }

        @Override
        public java.lang.Object getTags() {
            return this.tags;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("domainName", om.valueToTree(this.getDomainName()));
            if (this.getDomainNameConfigurations() != null) {
                obj.set("domainNameConfigurations", om.valueToTree(this.getDomainNameConfigurations()));
            }
            if (this.getTags() != null) {
                obj.set("tags", om.valueToTree(this.getTags()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnDomainNameV2Props.Jsii$Proxy that = (CfnDomainNameV2Props.Jsii$Proxy) o;

            if (!domainName.equals(that.domainName)) return false;
            if (this.domainNameConfigurations != null ? !this.domainNameConfigurations.equals(that.domainNameConfigurations) : that.domainNameConfigurations != null) return false;
            return this.tags != null ? this.tags.equals(that.tags) : that.tags == null;
        }

        @Override
        public int hashCode() {
            int result = this.domainName.hashCode();
            result = 31 * result + (this.domainNameConfigurations != null ? this.domainNameConfigurations.hashCode() : 0);
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            return result;
        }

    }
}

==> apigateway-1.10.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/apigateway/CfnDomainNameV2Props.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * Properties for defining a `AWS::ApiGatewayV2::DomainName`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-domainname.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.17.0 (build 7d5d104)", date = "2019-09-30T08:39:26.067Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnDomainNameV2Props extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::ApiGatewayV2::DomainName.DomainName`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-domainname.html#cfn-apigatewayv2-domainname-domainname
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getDomainName();

    /**
     * `AWS::ApiGatewayV2::DomainName.DomainNameConfigurations`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-domainname.html#cfn-apigatewayv2-domainname-domainnameconfigurations
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getDomainNameConfigurations();

    /**
     * `AWS::ApiGatewayV2::DomainName.Tags`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-domainname.html#cfn-apigatewayv2-domainname-tags
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getTags();

    /**
     * @return a {@link Builder} of {@link CfnDomainNameV2Props}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnDomainNameV2Props}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    public static final class Builder {
        private java.lang.String domainName;
        private java.lang.Object domainNameConfigurations;
        private java.lang.Object tags;

        /**
         * Sets the value of DomainName
         * @param domainName `AWS::ApiGatewayV2::DomainName.DomainName`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder domainName(java.lang.String domainName) {
            this.domainName = domainName;
            return this;
        }

        /**
         * Sets the value of DomainNameConfigurations
         * @param domainNameConfigurations `AWS::ApiGatewayV2::DomainName.DomainNameConfigurations`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder domainNameConfigurations(software.amazon.awscdk.core.IResolvable domainNameConfigurations) {
            this.domainNameConfigurations = domainNameConfigurations;
            return this;
        }

        /**
         * Sets the value of DomainNameConfigurations
         * @param domainNameConfigurations `AWS::ApiGatewayV2::DomainName.DomainNameConfigurations`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder domainNameConfigurations(java.util.List<java.lang.Object> domainNameConfigurations) {
            this.domainNameConfigurations = domainNameConfigurations;
            return this;
        }

        /**
         * Sets the value of Tags
         * @param tags `AWS::ApiGatewayV2::DomainName.Tags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder tags(java.lang.Object tags) {
            this.tags = tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnDomainNameV2Props}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnDomainNameV2Props build() {
            return new Jsii$Proxy(domainName, domainNameConfigurations, tags);
        }
    }

    /**
     * An implementation for {@link CfnDomainNameV2Props}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnDomainNameV2Props {
        private final java.lang.String domainName;
        private final java.lang.Object domainNameConfigurations;
        private final java.lang.Object tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.domainName = this.jsiiGet("domainName", java.lang.String.class);
            this.domainNameConfigurations = this.jsiiGet("domainNameConfigurations", java.lang.Object.class);
            this.tags = this.jsiiGet("tags", java.lang.Object.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.String domainName, java.lang.Object domainNameConfigurations, java.lang.Object tags) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.domainName = java.util.Objects.requireNonNull(domainName, "domainName is required");
            this.domainNameConfigurations = domainNameConfigurations;
            this.tags = tags;
        }

        @Override
        public java.lang.String getDomainName() {
            return this.domainName;
        }

        @Override
        public java.lang.Object getDomainNameConfigurations() {
            return this.domainNameConfigurations;
        }

        @Override
        public java.lang.Object getTags() {
            return this.tags;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("domainName", om.valueToTree(this.getDomainName()));
            if (this.getDomainNameConfigurations() != null) {
                obj.set("domainNameConfigurations", om.valueToTree(this.getDomainNameConfigurations()));
            }
            if (this.getTags() != null) {
                obj.set("tags", om.valueToTree(this.getTags()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnDomainNameV2Props.Jsii$Proxy that = (CfnDomainNameV2Props.Jsii$Proxy) o;

            if (!domainName.equals(that.domainName)) return false;
            if (this.domainNameConfigurations != null ? !this.domainNameConfigurations.equals(that.domainNameConfigurations) : that.domainNameConfigurations != null) return false;
            return this.tags != null ? this.tags.equals(that.tags) : that.tags == null;
        }

        @Override
        public int hashCode() {
            int result = this.domainName.hashCode();
            result = 31 * result + (this.domainNameConfigurations != null ? this.domainNameConfigurations.hashCode() : 0);
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            return result;
        }
    }
}
